@@ -54,7 +54,7 @@ class AutoscalersRestTransport(AutoscalersTransport):
         credentials: credentials.Credentials = None,
         credentials_file: str = None,
         scopes: Sequence[str] = None,
-        ssl_channel_credentials: grpc.ChannelCredentials = None,
+        client_cert_source_for_mtls: Callable[[], Tuple[bytes, bytes]] = None,
         quota_project_id: Optional[str] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
@@ -73,8 +73,9 @@ class AutoscalersRestTransport(AutoscalersTransport):
                 This argument is ignored if ``channel`` is provided.
             scopes (Optional(Sequence[str])): A list of scopes. This argument is
                 ignored if ``channel`` is provided.
-            ssl_channel_credentials (grpc.ChannelCredentials): SSL credentials
-                for grpc channel. It is ignored if ``channel`` is provided.
+            client_cert_source_for_mtls (Callable[[], Tuple[bytes, bytes]]): Client
+                certificate to configure mutual TLS HTTP channel. It is ignored
+                if ``channel`` is provided.
             quota_project_id (Optional[str]): An optional project to use for billing
                 and quota.
             client_info (google.api_core.gapic_v1.client_info.ClientInfo):	
@@ -89,6 +90,8 @@ class AutoscalersRestTransport(AutoscalersTransport):
             host=host, credentials=credentials, client_info=client_info,
         )
         self._session = AuthorizedSession(self._credentials)
+        if client_cert_source_for_mtls:
+            self._session.configure_mtls_channel(client_cert_source_for_mtls)
 
     def aggregated_list(
         self,
@@ -122,12 +125,12 @@ class AutoscalersRestTransport(AutoscalersTransport):
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
         query_params = {
-            "pageToken": request.page_token,
             "filter": request.filter,
-            "orderBy": request.order_by,
             "includeAllScopes": request.include_all_scopes,
-            "returnPartialSuccess": request.return_partial_success,
             "maxResults": request.max_results,
+            "orderBy": request.order_by,
+            "pageToken": request.page_token,
+            "returnPartialSuccess": request.return_partial_success,
         }
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
@@ -140,6 +143,9 @@ class AutoscalersRestTransport(AutoscalersTransport):
         # Send the request
         response = self._session.get(url)
 
+        # Raise requests.exceptions.HTTPError if the status code is >= 400
+        response.raise_for_status()
+
         # Return the response
         return compute.AutoscalerAggregatedList.from_json(response.content)
 
@@ -219,6 +225,9 @@ class AutoscalersRestTransport(AutoscalersTransport):
         # Send the request
         response = self._session.delete(url)
 
+        # Raise requests.exceptions.HTTPError if the status code is >= 400
+        response.raise_for_status()
+
         # Return the response
         return compute.Operation.from_json(response.content)
 
@@ -288,6 +297,9 @@ class AutoscalersRestTransport(AutoscalersTransport):
         # Send the request
         response = self._session.get(url)
 
+        # Raise requests.exceptions.HTTPError if the status code is >= 400
+        response.raise_for_status()
+
         # Return the response
         return compute.Autoscaler.from_json(response.content)
 
@@ -344,7 +356,9 @@ class AutoscalersRestTransport(AutoscalersTransport):
 
         # Jsonify the request body
         body = compute.Autoscaler.to_json(
-            request.autoscaler_resource, including_default_value_fields=False
+            request.autoscaler_resource,
+            including_default_value_fields=False,
+            use_integers_for_enums=False,
         )
 
         # TODO(yon-mg): need to handle grpc transcoding and parse url correctly
@@ -367,7 +381,10 @@ class AutoscalersRestTransport(AutoscalersTransport):
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.post(url, json=body,)
+        response = self._session.post(url, data=body,)
+
+        # Raise requests.exceptions.HTTPError if the status code is >= 400
+        response.raise_for_status()
 
         # Return the response
         return compute.Operation.from_json(response.content)
@@ -406,11 +423,11 @@ class AutoscalersRestTransport(AutoscalersTransport):
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
         query_params = {
-            "pageToken": request.page_token,
             "filter": request.filter,
-            "orderBy": request.order_by,
-            "returnPartialSuccess": request.return_partial_success,
             "maxResults": request.max_results,
+            "orderBy": request.order_by,
+            "pageToken": request.page_token,
+            "returnPartialSuccess": request.return_partial_success,
         }
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
@@ -423,6 +440,9 @@ class AutoscalersRestTransport(AutoscalersTransport):
         # Send the request
         response = self._session.get(url)
 
+        # Raise requests.exceptions.HTTPError if the status code is >= 400
+        response.raise_for_status()
+
         # Return the response
         return compute.AutoscalerList.from_json(response.content)
 
@@ -479,7 +499,9 @@ class AutoscalersRestTransport(AutoscalersTransport):
 
         # Jsonify the request body
         body = compute.Autoscaler.to_json(
-            request.autoscaler_resource, including_default_value_fields=False
+            request.autoscaler_resource,
+            including_default_value_fields=False,
+            use_integers_for_enums=False,
         )
 
         # TODO(yon-mg): need to handle grpc transcoding and parse url correctly
@@ -491,8 +513,8 @@ class AutoscalersRestTransport(AutoscalersTransport):
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
         query_params = {
-            "requestId": request.request_id,
             "autoscaler": request.autoscaler,
+            "requestId": request.request_id,
         }
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
@@ -503,7 +525,10 @@ class AutoscalersRestTransport(AutoscalersTransport):
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.patch(url, json=body,)
+        response = self._session.patch(url, data=body,)
+
+        # Raise requests.exceptions.HTTPError if the status code is >= 400
+        response.raise_for_status()
 
         # Return the response
         return compute.Operation.from_json(response.content)
@@ -561,7 +586,9 @@ class AutoscalersRestTransport(AutoscalersTransport):
 
         # Jsonify the request body
         body = compute.Autoscaler.to_json(
-            request.autoscaler_resource, including_default_value_fields=False
+            request.autoscaler_resource,
+            including_default_value_fields=False,
+            use_integers_for_enums=False,
         )
 
         # TODO(yon-mg): need to handle grpc transcoding and parse url correctly
@@ -573,8 +600,8 @@ class AutoscalersRestTransport(AutoscalersTransport):
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
         query_params = {
-            "requestId": request.request_id,
             "autoscaler": request.autoscaler,
+            "requestId": request.request_id,
         }
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
@@ -585,7 +612,10 @@ class AutoscalersRestTransport(AutoscalersTransport):
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.put(url, json=body,)
+        response = self._session.put(url, data=body,)
+
+        # Raise requests.exceptions.HTTPError if the status code is >= 400
+        response.raise_for_status()
 
         # Return the response
         return compute.Operation.from_json(response.content)
