@@ -32,6 +32,7 @@ from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+from google.cloud.compute_v1.services.global_network_endpoint_groups import pagers
 from google.cloud.compute_v1.types import compute
 
 from .transports.base import GlobalNetworkEndpointGroupsTransport, DEFAULT_CLIENT_INFO
@@ -270,21 +271,17 @@ class GlobalNetworkEndpointGroupsClient(
             util.strtobool(os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false"))
         )
 
-        ssl_credentials = None
+        client_cert_source_func = None
         is_mtls = False
         if use_client_cert:
             if client_options.client_cert_source:
-                import grpc  # type: ignore
-
-                cert, key = client_options.client_cert_source()
-                ssl_credentials = grpc.ssl_channel_credentials(
-                    certificate_chain=cert, private_key=key
-                )
                 is_mtls = True
+                client_cert_source_func = client_options.client_cert_source
             else:
-                creds = SslCredentials()
-                is_mtls = creds.is_mtls
-                ssl_credentials = creds.ssl_credentials if is_mtls else None
+                is_mtls = mtls.has_default_client_cert_source()
+                client_cert_source_func = (
+                    mtls.default_client_cert_source() if is_mtls else None
+                )
 
         # Figure out which api endpoint to use.
         if client_options.api_endpoint is not None:
@@ -327,7 +324,7 @@ class GlobalNetworkEndpointGroupsClient(
                 credentials_file=client_options.credentials_file,
                 host=api_endpoint,
                 scopes=client_options.scopes,
-                ssl_channel_credentials=ssl_credentials,
+                client_cert_source_for_mtls=client_cert_source_func,
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
             )
@@ -888,7 +885,7 @@ class GlobalNetworkEndpointGroupsClient(
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
-    ) -> compute.NetworkEndpointGroupList:
+    ) -> pagers.ListPager:
         r"""Retrieves the list of network endpoint groups that
         are located in the specified project.
 
@@ -910,7 +907,10 @@ class GlobalNetworkEndpointGroupsClient(
                 sent along with the request as metadata.
 
         Returns:
-            google.cloud.compute_v1.types.NetworkEndpointGroupList:
+            google.cloud.compute_v1.services.global_network_endpoint_groups.pagers.ListPager:
+                Iterating over this object will yield
+                results and resolve additional pages
+                automatically.
 
         """
         # Create or coerce a protobuf request object.
@@ -943,6 +943,12 @@ class GlobalNetworkEndpointGroupsClient(
         # Send the request.
         response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
 
+        # This method is paged; wrap the response in a pager, which provides
+        # an `__iter__` convenience method.
+        response = pagers.ListPager(
+            method=rpc, request=request, response=response, metadata=metadata,
+        )
+
         # Done; return the response.
         return response
 
@@ -955,7 +961,7 @@ class GlobalNetworkEndpointGroupsClient(
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
-    ) -> compute.NetworkEndpointGroupsListNetworkEndpoints:
+    ) -> pagers.ListNetworkEndpointsPager:
         r"""Lists the network endpoints in the specified network
         endpoint group.
 
@@ -986,7 +992,10 @@ class GlobalNetworkEndpointGroupsClient(
                 sent along with the request as metadata.
 
         Returns:
-            google.cloud.compute_v1.types.NetworkEndpointGroupsListNetworkEndpoints:
+            google.cloud.compute_v1.services.global_network_endpoint_groups.pagers.ListNetworkEndpointsPager:
+                Iterating over this object will yield
+                results and resolve additional pages
+                automatically.
 
         """
         # Create or coerce a protobuf request object.
@@ -1025,6 +1034,12 @@ class GlobalNetworkEndpointGroupsClient(
         # Send the request.
         response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
 
+        # This method is paged; wrap the response in a pager, which provides
+        # an `__iter__` convenience method.
+        response = pagers.ListNetworkEndpointsPager(
+            method=rpc, request=request, response=response, metadata=metadata,
+        )
+
         # Done; return the response.
         return response
 
