@@ -54,7 +54,7 @@ class GlobalOrganizationOperationsRestTransport(GlobalOrganizationOperationsTran
         credentials: credentials.Credentials = None,
         credentials_file: str = None,
         scopes: Sequence[str] = None,
-        ssl_channel_credentials: grpc.ChannelCredentials = None,
+        client_cert_source_for_mtls: Callable[[], Tuple[bytes, bytes]] = None,
         quota_project_id: Optional[str] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
@@ -73,8 +73,9 @@ class GlobalOrganizationOperationsRestTransport(GlobalOrganizationOperationsTran
                 This argument is ignored if ``channel`` is provided.
             scopes (Optional(Sequence[str])): A list of scopes. This argument is
                 ignored if ``channel`` is provided.
-            ssl_channel_credentials (grpc.ChannelCredentials): SSL credentials
-                for grpc channel. It is ignored if ``channel`` is provided.
+            client_cert_source_for_mtls (Callable[[], Tuple[bytes, bytes]]): Client
+                certificate to configure mutual TLS HTTP channel. It is ignored
+                if ``channel`` is provided.
             quota_project_id (Optional[str]): An optional project to use for billing
                 and quota.
             client_info (google.api_core.gapic_v1.client_info.ClientInfo):	
@@ -89,6 +90,8 @@ class GlobalOrganizationOperationsRestTransport(GlobalOrganizationOperationsTran
             host=host, credentials=credentials, client_info=client_info,
         )
         self._session = AuthorizedSession(self._credentials)
+        if client_cert_source_for_mtls:
+            self._session.configure_mtls_channel(client_cert_source_for_mtls)
 
     def delete(
         self,
@@ -138,6 +141,9 @@ class GlobalOrganizationOperationsRestTransport(GlobalOrganizationOperationsTran
         # Send the request
         response = self._session.delete(url)
 
+        # Raise requests.exceptions.HTTPError if the status code is >= 400
+        response.raise_for_status()
+
         # Return the response
         return compute.DeleteGlobalOrganizationOperationResponse.from_json(
             response.content
@@ -216,6 +222,9 @@ class GlobalOrganizationOperationsRestTransport(GlobalOrganizationOperationsTran
         # Send the request
         response = self._session.get(url)
 
+        # Raise requests.exceptions.HTTPError if the status code is >= 400
+        response.raise_for_status()
+
         # Return the response
         return compute.Operation.from_json(response.content)
 
@@ -253,12 +262,12 @@ class GlobalOrganizationOperationsRestTransport(GlobalOrganizationOperationsTran
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
         query_params = {
+            "filter": request.filter,
+            "maxResults": request.max_results,
+            "orderBy": request.order_by,
             "pageToken": request.page_token,
             "parentId": request.parent_id,
             "returnPartialSuccess": request.return_partial_success,
-            "filter": request.filter,
-            "orderBy": request.order_by,
-            "maxResults": request.max_results,
         }
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
@@ -271,6 +280,9 @@ class GlobalOrganizationOperationsRestTransport(GlobalOrganizationOperationsTran
         # Send the request
         response = self._session.get(url)
 
+        # Raise requests.exceptions.HTTPError if the status code is >= 400
+        response.raise_for_status()
+
         # Return the response
         return compute.OperationList.from_json(response.content)
 
