@@ -32,6 +32,7 @@ from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+from google.cloud.compute_v1.services.instance_groups import pagers
 from google.cloud.compute_v1.types import compute
 
 from .transports.base import InstanceGroupsTransport, DEFAULT_CLIENT_INFO
@@ -266,21 +267,17 @@ class InstanceGroupsClient(metaclass=InstanceGroupsClientMeta):
             util.strtobool(os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false"))
         )
 
-        ssl_credentials = None
+        client_cert_source_func = None
         is_mtls = False
         if use_client_cert:
             if client_options.client_cert_source:
-                import grpc  # type: ignore
-
-                cert, key = client_options.client_cert_source()
-                ssl_credentials = grpc.ssl_channel_credentials(
-                    certificate_chain=cert, private_key=key
-                )
                 is_mtls = True
+                client_cert_source_func = client_options.client_cert_source
             else:
-                creds = SslCredentials()
-                is_mtls = creds.is_mtls
-                ssl_credentials = creds.ssl_credentials if is_mtls else None
+                is_mtls = mtls.has_default_client_cert_source()
+                client_cert_source_func = (
+                    mtls.default_client_cert_source() if is_mtls else None
+                )
 
         # Figure out which api endpoint to use.
         if client_options.api_endpoint is not None:
@@ -323,7 +320,7 @@ class InstanceGroupsClient(metaclass=InstanceGroupsClientMeta):
                 credentials_file=client_options.credentials_file,
                 host=api_endpoint,
                 scopes=client_options.scopes,
-                ssl_channel_credentials=ssl_credentials,
+                client_cert_source_for_mtls=client_cert_source_func,
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
             )
@@ -466,7 +463,7 @@ class InstanceGroupsClient(metaclass=InstanceGroupsClientMeta):
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
-    ) -> compute.InstanceGroupAggregatedList:
+    ) -> pagers.AggregatedListPager:
         r"""Retrieves the list of instance groups and sorts them
         by zone.
 
@@ -488,7 +485,10 @@ class InstanceGroupsClient(metaclass=InstanceGroupsClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            google.cloud.compute_v1.types.InstanceGroupAggregatedList:
+            google.cloud.compute_v1.services.instance_groups.pagers.AggregatedListPager:
+                Iterating over this object will yield
+                results and resolve additional pages
+                automatically.
 
         """
         # Create or coerce a protobuf request object.
@@ -521,6 +521,12 @@ class InstanceGroupsClient(metaclass=InstanceGroupsClientMeta):
         # Send the request.
         response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
 
+        # This method is paged; wrap the response in a pager, which provides
+        # an `__iter__` convenience method.
+        response = pagers.AggregatedListPager(
+            method=rpc, request=request, response=response, metadata=metadata,
+        )
+
         # Done; return the response.
         return response
 
@@ -864,7 +870,7 @@ class InstanceGroupsClient(metaclass=InstanceGroupsClientMeta):
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
-    ) -> compute.InstanceGroupList:
+    ) -> pagers.ListPager:
         r"""Retrieves the list of zonal instance group resources
         contained within the specified zone.
         For managed instance groups, use the
@@ -896,8 +902,12 @@ class InstanceGroupsClient(metaclass=InstanceGroupsClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            google.cloud.compute_v1.types.InstanceGroupList:
+            google.cloud.compute_v1.services.instance_groups.pagers.ListPager:
                 A list of InstanceGroup resources.
+                Iterating over this object will yield
+                results and resolve additional pages
+                automatically.
+
         """
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
@@ -931,6 +941,12 @@ class InstanceGroupsClient(metaclass=InstanceGroupsClientMeta):
         # Send the request.
         response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
 
+        # This method is paged; wrap the response in a pager, which provides
+        # an `__iter__` convenience method.
+        response = pagers.ListPager(
+            method=rpc, request=request, response=response, metadata=metadata,
+        )
+
         # Done; return the response.
         return response
 
@@ -945,7 +961,7 @@ class InstanceGroupsClient(metaclass=InstanceGroupsClientMeta):
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
-    ) -> compute.InstanceGroupsListInstances:
+    ) -> pagers.ListInstancesPager:
         r"""Lists the instances in the specified instance group.
         The orderBy query parameter is not supported.
 
@@ -987,7 +1003,10 @@ class InstanceGroupsClient(metaclass=InstanceGroupsClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            google.cloud.compute_v1.types.InstanceGroupsListInstances:
+            google.cloud.compute_v1.services.instance_groups.pagers.ListInstancesPager:
+                Iterating over this object will yield
+                results and resolve additional pages
+                automatically.
 
         """
         # Create or coerce a protobuf request object.
@@ -1035,6 +1054,12 @@ class InstanceGroupsClient(metaclass=InstanceGroupsClientMeta):
         # Send the request.
         response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
 
+        # This method is paged; wrap the response in a pager, which provides
+        # an `__iter__` convenience method.
+        response = pagers.ListInstancesPager(
+            method=rpc, request=request, response=response, metadata=metadata,
+        )
+
         # Done; return the response.
         return response
 
