@@ -32,6 +32,7 @@ from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+from google.cloud.compute_v1.services.interconnect_attachments import pagers
 from google.cloud.compute_v1.types import compute
 
 from .transports.base import InterconnectAttachmentsTransport, DEFAULT_CLIENT_INFO
@@ -268,21 +269,17 @@ class InterconnectAttachmentsClient(metaclass=InterconnectAttachmentsClientMeta)
             util.strtobool(os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false"))
         )
 
-        ssl_credentials = None
+        client_cert_source_func = None
         is_mtls = False
         if use_client_cert:
             if client_options.client_cert_source:
-                import grpc  # type: ignore
-
-                cert, key = client_options.client_cert_source()
-                ssl_credentials = grpc.ssl_channel_credentials(
-                    certificate_chain=cert, private_key=key
-                )
                 is_mtls = True
+                client_cert_source_func = client_options.client_cert_source
             else:
-                creds = SslCredentials()
-                is_mtls = creds.is_mtls
-                ssl_credentials = creds.ssl_credentials if is_mtls else None
+                is_mtls = mtls.has_default_client_cert_source()
+                client_cert_source_func = (
+                    mtls.default_client_cert_source() if is_mtls else None
+                )
 
         # Figure out which api endpoint to use.
         if client_options.api_endpoint is not None:
@@ -325,7 +322,7 @@ class InterconnectAttachmentsClient(metaclass=InterconnectAttachmentsClientMeta)
                 credentials_file=client_options.credentials_file,
                 host=api_endpoint,
                 scopes=client_options.scopes,
-                ssl_channel_credentials=ssl_credentials,
+                client_cert_source_for_mtls=client_cert_source_func,
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
             )
@@ -338,7 +335,7 @@ class InterconnectAttachmentsClient(metaclass=InterconnectAttachmentsClientMeta)
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
-    ) -> compute.InterconnectAttachmentAggregatedList:
+    ) -> pagers.AggregatedListPager:
         r"""Retrieves an aggregated list of interconnect
         attachments.
 
@@ -360,7 +357,10 @@ class InterconnectAttachmentsClient(metaclass=InterconnectAttachmentsClientMeta)
                 sent along with the request as metadata.
 
         Returns:
-            google.cloud.compute_v1.types.InterconnectAttachmentAggregatedList:
+            google.cloud.compute_v1.services.interconnect_attachments.pagers.AggregatedListPager:
+                Iterating over this object will yield
+                results and resolve additional pages
+                automatically.
 
         """
         # Create or coerce a protobuf request object.
@@ -395,6 +395,12 @@ class InterconnectAttachmentsClient(metaclass=InterconnectAttachmentsClientMeta)
         # Send the request.
         response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
 
+        # This method is paged; wrap the response in a pager, which provides
+        # an `__iter__` convenience method.
+        response = pagers.AggregatedListPager(
+            method=rpc, request=request, response=response, metadata=metadata,
+        )
+
         # Done; return the response.
         return response
 
@@ -715,7 +721,7 @@ class InterconnectAttachmentsClient(metaclass=InterconnectAttachmentsClientMeta)
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
-    ) -> compute.InterconnectAttachmentList:
+    ) -> pagers.ListPager:
         r"""Retrieves the list of interconnect attachments
         contained within the specified region.
 
@@ -742,10 +748,12 @@ class InterconnectAttachmentsClient(metaclass=InterconnectAttachmentsClientMeta)
                 sent along with the request as metadata.
 
         Returns:
-            google.cloud.compute_v1.types.InterconnectAttachmentList:
+            google.cloud.compute_v1.services.interconnect_attachments.pagers.ListPager:
                 Response to the list request, and
                 contains a list of interconnect
-                attachments.
+                attachments.  Iterating over this object
+                will yield results and resolve
+                additional pages automatically.
 
         """
         # Create or coerce a protobuf request object.
@@ -780,6 +788,12 @@ class InterconnectAttachmentsClient(metaclass=InterconnectAttachmentsClientMeta)
         # Send the request.
         response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
 
+        # This method is paged; wrap the response in a pager, which provides
+        # an `__iter__` convenience method.
+        response = pagers.ListPager(
+            method=rpc, request=request, response=response, metadata=metadata,
+        )
+
         # Done; return the response.
         return response
 
