@@ -32,6 +32,7 @@ from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+from google.cloud.compute_v1.services.node_groups import pagers
 from google.cloud.compute_v1.types import compute
 
 from .transports.base import NodeGroupsTransport, DEFAULT_CLIENT_INFO
@@ -264,21 +265,17 @@ class NodeGroupsClient(metaclass=NodeGroupsClientMeta):
             util.strtobool(os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false"))
         )
 
-        ssl_credentials = None
+        client_cert_source_func = None
         is_mtls = False
         if use_client_cert:
             if client_options.client_cert_source:
-                import grpc  # type: ignore
-
-                cert, key = client_options.client_cert_source()
-                ssl_credentials = grpc.ssl_channel_credentials(
-                    certificate_chain=cert, private_key=key
-                )
                 is_mtls = True
+                client_cert_source_func = client_options.client_cert_source
             else:
-                creds = SslCredentials()
-                is_mtls = creds.is_mtls
-                ssl_credentials = creds.ssl_credentials if is_mtls else None
+                is_mtls = mtls.has_default_client_cert_source()
+                client_cert_source_func = (
+                    mtls.default_client_cert_source() if is_mtls else None
+                )
 
         # Figure out which api endpoint to use.
         if client_options.api_endpoint is not None:
@@ -321,7 +318,7 @@ class NodeGroupsClient(metaclass=NodeGroupsClientMeta):
                 credentials_file=client_options.credentials_file,
                 host=api_endpoint,
                 scopes=client_options.scopes,
-                ssl_channel_credentials=ssl_credentials,
+                client_cert_source_for_mtls=client_cert_source_func,
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
             )
@@ -454,7 +451,7 @@ class NodeGroupsClient(metaclass=NodeGroupsClientMeta):
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
-    ) -> compute.NodeGroupAggregatedList:
+    ) -> pagers.AggregatedListPager:
         r"""Retrieves an aggregated list of node groups. Note:
         use nodeGroups.listNodes for more details about each
         group.
@@ -477,7 +474,10 @@ class NodeGroupsClient(metaclass=NodeGroupsClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            google.cloud.compute_v1.types.NodeGroupAggregatedList:
+            google.cloud.compute_v1.services.node_groups.pagers.AggregatedListPager:
+                Iterating over this object will yield
+                results and resolve additional pages
+                automatically.
 
         """
         # Create or coerce a protobuf request object.
@@ -510,6 +510,12 @@ class NodeGroupsClient(metaclass=NodeGroupsClientMeta):
         # Send the request.
         response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
 
+        # This method is paged; wrap the response in a pager, which provides
+        # an `__iter__` convenience method.
+        response = pagers.AggregatedListPager(
+            method=rpc, request=request, response=response, metadata=metadata,
+        )
+
         # Done; return the response.
         return response
 
@@ -1107,7 +1113,7 @@ class NodeGroupsClient(metaclass=NodeGroupsClientMeta):
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
-    ) -> compute.NodeGroupList:
+    ) -> pagers.ListPager:
         r"""Retrieves a list of node groups available to the
         specified project. Note: use nodeGroups.listNodes for
         more details about each group.
@@ -1136,8 +1142,12 @@ class NodeGroupsClient(metaclass=NodeGroupsClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            google.cloud.compute_v1.types.NodeGroupList:
+            google.cloud.compute_v1.services.node_groups.pagers.ListPager:
                 Contains a list of nodeGroups.
+                Iterating over this object will yield
+                results and resolve additional pages
+                automatically.
+
         """
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
@@ -1171,6 +1181,12 @@ class NodeGroupsClient(metaclass=NodeGroupsClientMeta):
         # Send the request.
         response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
 
+        # This method is paged; wrap the response in a pager, which provides
+        # an `__iter__` convenience method.
+        response = pagers.ListPager(
+            method=rpc, request=request, response=response, metadata=metadata,
+        )
+
         # Done; return the response.
         return response
 
@@ -1184,7 +1200,7 @@ class NodeGroupsClient(metaclass=NodeGroupsClientMeta):
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
-    ) -> compute.NodeGroupsListNodes:
+    ) -> pagers.ListNodesPager:
         r"""Lists nodes in the node group.
 
         Args:
@@ -1219,7 +1235,10 @@ class NodeGroupsClient(metaclass=NodeGroupsClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            google.cloud.compute_v1.types.NodeGroupsListNodes:
+            google.cloud.compute_v1.services.node_groups.pagers.ListNodesPager:
+                Iterating over this object will yield
+                results and resolve additional pages
+                automatically.
 
         """
         # Create or coerce a protobuf request object.
@@ -1256,6 +1275,12 @@ class NodeGroupsClient(metaclass=NodeGroupsClientMeta):
         # Send the request.
         response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
 
+        # This method is paged; wrap the response in a pager, which provides
+        # an `__iter__` convenience method.
+        response = pagers.ListNodesPager(
+            method=rpc, request=request, response=response, metadata=metadata,
+        )
+
         # Done; return the response.
         return response
 
