@@ -54,7 +54,7 @@ class RegionInstanceGroupManagersRestTransport(RegionInstanceGroupManagersTransp
         credentials: credentials.Credentials = None,
         credentials_file: str = None,
         scopes: Sequence[str] = None,
-        ssl_channel_credentials: grpc.ChannelCredentials = None,
+        client_cert_source_for_mtls: Callable[[], Tuple[bytes, bytes]] = None,
         quota_project_id: Optional[str] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
@@ -73,8 +73,9 @@ class RegionInstanceGroupManagersRestTransport(RegionInstanceGroupManagersTransp
                 This argument is ignored if ``channel`` is provided.
             scopes (Optional(Sequence[str])): A list of scopes. This argument is
                 ignored if ``channel`` is provided.
-            ssl_channel_credentials (grpc.ChannelCredentials): SSL credentials
-                for grpc channel. It is ignored if ``channel`` is provided.
+            client_cert_source_for_mtls (Callable[[], Tuple[bytes, bytes]]): Client
+                certificate to configure mutual TLS HTTP channel. It is ignored
+                if ``channel`` is provided.
             quota_project_id (Optional[str]): An optional project to use for billing
                 and quota.
             client_info (google.api_core.gapic_v1.client_info.ClientInfo):	
@@ -89,6 +90,8 @@ class RegionInstanceGroupManagersRestTransport(RegionInstanceGroupManagersTransp
             host=host, credentials=credentials, client_info=client_info,
         )
         self._session = AuthorizedSession(self._credentials)
+        if client_cert_source_for_mtls:
+            self._session.configure_mtls_channel(client_cert_source_for_mtls)
 
     def abandon_instances(
         self,
@@ -145,6 +148,7 @@ class RegionInstanceGroupManagersRestTransport(RegionInstanceGroupManagersTransp
         body = compute.RegionInstanceGroupManagersAbandonInstancesRequest.to_json(
             request.region_instance_group_managers_abandon_instances_request_resource,
             including_default_value_fields=False,
+            use_integers_for_enums=False,
         )
 
         # TODO(yon-mg): need to handle grpc transcoding and parse url correctly
@@ -170,7 +174,10 @@ class RegionInstanceGroupManagersRestTransport(RegionInstanceGroupManagersTransp
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.post(url, json=body,)
+        response = self._session.post(url, data=body,)
+
+        # Raise requests.exceptions.HTTPError if the status code is >= 400
+        response.raise_for_status()
 
         # Return the response
         return compute.Operation.from_json(response.content)
@@ -231,6 +238,7 @@ class RegionInstanceGroupManagersRestTransport(RegionInstanceGroupManagersTransp
         body = compute.RegionInstanceGroupManagersApplyUpdatesRequest.to_json(
             request.region_instance_group_managers_apply_updates_request_resource,
             including_default_value_fields=False,
+            use_integers_for_enums=False,
         )
 
         # TODO(yon-mg): need to handle grpc transcoding and parse url correctly
@@ -254,7 +262,10 @@ class RegionInstanceGroupManagersRestTransport(RegionInstanceGroupManagersTransp
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.post(url, json=body,)
+        response = self._session.post(url, data=body,)
+
+        # Raise requests.exceptions.HTTPError if the status code is >= 400
+        response.raise_for_status()
 
         # Return the response
         return compute.Operation.from_json(response.content)
@@ -314,6 +325,7 @@ class RegionInstanceGroupManagersRestTransport(RegionInstanceGroupManagersTransp
         body = compute.RegionInstanceGroupManagersCreateInstancesRequest.to_json(
             request.region_instance_group_managers_create_instances_request_resource,
             including_default_value_fields=False,
+            use_integers_for_enums=False,
         )
 
         # TODO(yon-mg): need to handle grpc transcoding and parse url correctly
@@ -339,7 +351,10 @@ class RegionInstanceGroupManagersRestTransport(RegionInstanceGroupManagersTransp
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.post(url, json=body,)
+        response = self._session.post(url, data=body,)
+
+        # Raise requests.exceptions.HTTPError if the status code is >= 400
+        response.raise_for_status()
 
         # Return the response
         return compute.Operation.from_json(response.content)
@@ -420,6 +435,9 @@ class RegionInstanceGroupManagersRestTransport(RegionInstanceGroupManagersTransp
         # Send the request
         response = self._session.delete(url)
 
+        # Raise requests.exceptions.HTTPError if the status code is >= 400
+        response.raise_for_status()
+
         # Return the response
         return compute.Operation.from_json(response.content)
 
@@ -478,6 +496,7 @@ class RegionInstanceGroupManagersRestTransport(RegionInstanceGroupManagersTransp
         body = compute.RegionInstanceGroupManagersDeleteInstancesRequest.to_json(
             request.region_instance_group_managers_delete_instances_request_resource,
             including_default_value_fields=False,
+            use_integers_for_enums=False,
         )
 
         # TODO(yon-mg): need to handle grpc transcoding and parse url correctly
@@ -503,7 +522,10 @@ class RegionInstanceGroupManagersRestTransport(RegionInstanceGroupManagersTransp
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.post(url, json=body,)
+        response = self._session.post(url, data=body,)
+
+        # Raise requests.exceptions.HTTPError if the status code is >= 400
+        response.raise_for_status()
 
         # Return the response
         return compute.Operation.from_json(response.content)
@@ -564,6 +586,7 @@ class RegionInstanceGroupManagersRestTransport(RegionInstanceGroupManagersTransp
         body = compute.RegionInstanceGroupManagerDeleteInstanceConfigReq.to_json(
             request.region_instance_group_manager_delete_instance_config_req_resource,
             including_default_value_fields=False,
+            use_integers_for_enums=False,
         )
 
         # TODO(yon-mg): need to handle grpc transcoding and parse url correctly
@@ -587,7 +610,10 @@ class RegionInstanceGroupManagersRestTransport(RegionInstanceGroupManagersTransp
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.post(url, json=body,)
+        response = self._session.post(url, data=body,)
+
+        # Raise requests.exceptions.HTTPError if the status code is >= 400
+        response.raise_for_status()
 
         # Return the response
         return compute.Operation.from_json(response.content)
@@ -652,6 +678,9 @@ class RegionInstanceGroupManagersRestTransport(RegionInstanceGroupManagersTransp
         # Send the request
         response = self._session.get(url)
 
+        # Raise requests.exceptions.HTTPError if the status code is >= 400
+        response.raise_for_status()
+
         # Return the response
         return compute.InstanceGroupManager.from_json(response.content)
 
@@ -710,6 +739,7 @@ class RegionInstanceGroupManagersRestTransport(RegionInstanceGroupManagersTransp
         body = compute.InstanceGroupManager.to_json(
             request.instance_group_manager_resource,
             including_default_value_fields=False,
+            use_integers_for_enums=False,
         )
 
         # TODO(yon-mg): need to handle grpc transcoding and parse url correctly
@@ -732,7 +762,10 @@ class RegionInstanceGroupManagersRestTransport(RegionInstanceGroupManagersTransp
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.post(url, json=body,)
+        response = self._session.post(url, data=body,)
+
+        # Raise requests.exceptions.HTTPError if the status code is >= 400
+        response.raise_for_status()
 
         # Return the response
         return compute.Operation.from_json(response.content)
@@ -771,11 +804,11 @@ class RegionInstanceGroupManagersRestTransport(RegionInstanceGroupManagersTransp
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
         query_params = {
-            "pageToken": request.page_token,
             "filter": request.filter,
-            "orderBy": request.order_by,
-            "returnPartialSuccess": request.return_partial_success,
             "maxResults": request.max_results,
+            "orderBy": request.order_by,
+            "pageToken": request.page_token,
+            "returnPartialSuccess": request.return_partial_success,
         }
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
@@ -788,6 +821,9 @@ class RegionInstanceGroupManagersRestTransport(RegionInstanceGroupManagersTransp
         # Send the request
         response = self._session.get(url)
 
+        # Raise requests.exceptions.HTTPError if the status code is >= 400
+        response.raise_for_status()
+
         # Return the response
         return compute.RegionInstanceGroupManagerList.from_json(response.content)
 
@@ -826,11 +862,11 @@ class RegionInstanceGroupManagersRestTransport(RegionInstanceGroupManagersTransp
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
         query_params = {
-            "pageToken": request.page_token,
             "filter": request.filter,
-            "orderBy": request.order_by,
-            "returnPartialSuccess": request.return_partial_success,
             "maxResults": request.max_results,
+            "orderBy": request.order_by,
+            "pageToken": request.page_token,
+            "returnPartialSuccess": request.return_partial_success,
         }
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
@@ -843,6 +879,9 @@ class RegionInstanceGroupManagersRestTransport(RegionInstanceGroupManagersTransp
         # Send the request
         response = self._session.get(url)
 
+        # Raise requests.exceptions.HTTPError if the status code is >= 400
+        response.raise_for_status()
+
         # Return the response
         return compute.RegionInstanceGroupManagersListErrorsResponse.from_json(
             response.content
@@ -883,11 +922,11 @@ class RegionInstanceGroupManagersRestTransport(RegionInstanceGroupManagersTransp
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
         query_params = {
-            "pageToken": request.page_token,
             "filter": request.filter,
-            "orderBy": request.order_by,
-            "returnPartialSuccess": request.return_partial_success,
             "maxResults": request.max_results,
+            "orderBy": request.order_by,
+            "pageToken": request.page_token,
+            "returnPartialSuccess": request.return_partial_success,
         }
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
@@ -900,6 +939,9 @@ class RegionInstanceGroupManagersRestTransport(RegionInstanceGroupManagersTransp
         # Send the request
         response = self._session.post(url)
 
+        # Raise requests.exceptions.HTTPError if the status code is >= 400
+        response.raise_for_status()
+
         # Return the response
         return compute.RegionInstanceGroupManagersListInstancesResponse.from_json(
             response.content
@@ -940,11 +982,11 @@ class RegionInstanceGroupManagersRestTransport(RegionInstanceGroupManagersTransp
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
         query_params = {
-            "pageToken": request.page_token,
             "filter": request.filter,
-            "orderBy": request.order_by,
-            "returnPartialSuccess": request.return_partial_success,
             "maxResults": request.max_results,
+            "orderBy": request.order_by,
+            "pageToken": request.page_token,
+            "returnPartialSuccess": request.return_partial_success,
         }
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
@@ -957,6 +999,9 @@ class RegionInstanceGroupManagersRestTransport(RegionInstanceGroupManagersTransp
         # Send the request
         response = self._session.post(url)
 
+        # Raise requests.exceptions.HTTPError if the status code is >= 400
+        response.raise_for_status()
+
         # Return the response
         return compute.RegionInstanceGroupManagersListInstanceConfigsResp.from_json(
             response.content
@@ -1017,6 +1062,7 @@ class RegionInstanceGroupManagersRestTransport(RegionInstanceGroupManagersTransp
         body = compute.InstanceGroupManager.to_json(
             request.instance_group_manager_resource,
             including_default_value_fields=False,
+            use_integers_for_enums=False,
         )
 
         # TODO(yon-mg): need to handle grpc transcoding and parse url correctly
@@ -1042,7 +1088,10 @@ class RegionInstanceGroupManagersRestTransport(RegionInstanceGroupManagersTransp
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.patch(url, json=body,)
+        response = self._session.patch(url, data=body,)
+
+        # Raise requests.exceptions.HTTPError if the status code is >= 400
+        response.raise_for_status()
 
         # Return the response
         return compute.Operation.from_json(response.content)
@@ -1103,6 +1152,7 @@ class RegionInstanceGroupManagersRestTransport(RegionInstanceGroupManagersTransp
         body = compute.RegionInstanceGroupManagerPatchInstanceConfigReq.to_json(
             request.region_instance_group_manager_patch_instance_config_req_resource,
             including_default_value_fields=False,
+            use_integers_for_enums=False,
         )
 
         # TODO(yon-mg): need to handle grpc transcoding and parse url correctly
@@ -1128,7 +1178,10 @@ class RegionInstanceGroupManagersRestTransport(RegionInstanceGroupManagersTransp
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.post(url, json=body,)
+        response = self._session.post(url, data=body,)
+
+        # Raise requests.exceptions.HTTPError if the status code is >= 400
+        response.raise_for_status()
 
         # Return the response
         return compute.Operation.from_json(response.content)
@@ -1188,6 +1241,7 @@ class RegionInstanceGroupManagersRestTransport(RegionInstanceGroupManagersTransp
         body = compute.RegionInstanceGroupManagersRecreateRequest.to_json(
             request.region_instance_group_managers_recreate_request_resource,
             including_default_value_fields=False,
+            use_integers_for_enums=False,
         )
 
         # TODO(yon-mg): need to handle grpc transcoding and parse url correctly
@@ -1213,7 +1267,10 @@ class RegionInstanceGroupManagersRestTransport(RegionInstanceGroupManagersTransp
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.post(url, json=body,)
+        response = self._session.post(url, data=body,)
+
+        # Raise requests.exceptions.HTTPError if the status code is >= 400
+        response.raise_for_status()
 
         # Return the response
         return compute.Operation.from_json(response.content)
@@ -1295,6 +1352,9 @@ class RegionInstanceGroupManagersRestTransport(RegionInstanceGroupManagersTransp
         # Send the request
         response = self._session.post(url)
 
+        # Raise requests.exceptions.HTTPError if the status code is >= 400
+        response.raise_for_status()
+
         # Return the response
         return compute.Operation.from_json(response.content)
 
@@ -1353,6 +1413,7 @@ class RegionInstanceGroupManagersRestTransport(RegionInstanceGroupManagersTransp
         body = compute.RegionInstanceGroupManagersSetTemplateRequest.to_json(
             request.region_instance_group_managers_set_template_request_resource,
             including_default_value_fields=False,
+            use_integers_for_enums=False,
         )
 
         # TODO(yon-mg): need to handle grpc transcoding and parse url correctly
@@ -1378,7 +1439,10 @@ class RegionInstanceGroupManagersRestTransport(RegionInstanceGroupManagersTransp
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.post(url, json=body,)
+        response = self._session.post(url, data=body,)
+
+        # Raise requests.exceptions.HTTPError if the status code is >= 400
+        response.raise_for_status()
 
         # Return the response
         return compute.Operation.from_json(response.content)
@@ -1438,6 +1502,7 @@ class RegionInstanceGroupManagersRestTransport(RegionInstanceGroupManagersTransp
         body = compute.RegionInstanceGroupManagersSetTargetPoolsRequest.to_json(
             request.region_instance_group_managers_set_target_pools_request_resource,
             including_default_value_fields=False,
+            use_integers_for_enums=False,
         )
 
         # TODO(yon-mg): need to handle grpc transcoding and parse url correctly
@@ -1463,7 +1528,10 @@ class RegionInstanceGroupManagersRestTransport(RegionInstanceGroupManagersTransp
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.post(url, json=body,)
+        response = self._session.post(url, data=body,)
+
+        # Raise requests.exceptions.HTTPError if the status code is >= 400
+        response.raise_for_status()
 
         # Return the response
         return compute.Operation.from_json(response.content)
@@ -1524,6 +1592,7 @@ class RegionInstanceGroupManagersRestTransport(RegionInstanceGroupManagersTransp
         body = compute.RegionInstanceGroupManagerUpdateInstanceConfigReq.to_json(
             request.region_instance_group_manager_update_instance_config_req_resource,
             including_default_value_fields=False,
+            use_integers_for_enums=False,
         )
 
         # TODO(yon-mg): need to handle grpc transcoding and parse url correctly
@@ -1549,7 +1618,10 @@ class RegionInstanceGroupManagersRestTransport(RegionInstanceGroupManagersTransp
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.post(url, json=body,)
+        response = self._session.post(url, data=body,)
+
+        # Raise requests.exceptions.HTTPError if the status code is >= 400
+        response.raise_for_status()
 
         # Return the response
         return compute.Operation.from_json(response.content)
