@@ -54,7 +54,7 @@ class RegionNetworkEndpointGroupsRestTransport(RegionNetworkEndpointGroupsTransp
         credentials: credentials.Credentials = None,
         credentials_file: str = None,
         scopes: Sequence[str] = None,
-        ssl_channel_credentials: grpc.ChannelCredentials = None,
+        client_cert_source_for_mtls: Callable[[], Tuple[bytes, bytes]] = None,
         quota_project_id: Optional[str] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
@@ -73,8 +73,9 @@ class RegionNetworkEndpointGroupsRestTransport(RegionNetworkEndpointGroupsTransp
                 This argument is ignored if ``channel`` is provided.
             scopes (Optional(Sequence[str])): A list of scopes. This argument is
                 ignored if ``channel`` is provided.
-            ssl_channel_credentials (grpc.ChannelCredentials): SSL credentials
-                for grpc channel. It is ignored if ``channel`` is provided.
+            client_cert_source_for_mtls (Callable[[], Tuple[bytes, bytes]]): Client
+                certificate to configure mutual TLS HTTP channel. It is ignored
+                if ``channel`` is provided.
             quota_project_id (Optional[str]): An optional project to use for billing
                 and quota.
             client_info (google.api_core.gapic_v1.client_info.ClientInfo):	
@@ -89,6 +90,8 @@ class RegionNetworkEndpointGroupsRestTransport(RegionNetworkEndpointGroupsTransp
             host=host, credentials=credentials, client_info=client_info,
         )
         self._session = AuthorizedSession(self._credentials)
+        if client_cert_source_for_mtls:
+            self._session.configure_mtls_channel(client_cert_source_for_mtls)
 
     def delete(
         self,
@@ -166,6 +169,9 @@ class RegionNetworkEndpointGroupsRestTransport(RegionNetworkEndpointGroupsTransp
         # Send the request
         response = self._session.delete(url)
 
+        # Raise requests.exceptions.HTTPError if the status code is >= 400
+        response.raise_for_status()
+
         # Return the response
         return compute.Operation.from_json(response.content)
 
@@ -228,6 +234,9 @@ class RegionNetworkEndpointGroupsRestTransport(RegionNetworkEndpointGroupsTransp
         # Send the request
         response = self._session.get(url)
 
+        # Raise requests.exceptions.HTTPError if the status code is >= 400
+        response.raise_for_status()
+
         # Return the response
         return compute.NetworkEndpointGroup.from_json(response.content)
 
@@ -286,6 +295,7 @@ class RegionNetworkEndpointGroupsRestTransport(RegionNetworkEndpointGroupsTransp
         body = compute.NetworkEndpointGroup.to_json(
             request.network_endpoint_group_resource,
             including_default_value_fields=False,
+            use_integers_for_enums=False,
         )
 
         # TODO(yon-mg): need to handle grpc transcoding and parse url correctly
@@ -308,7 +318,10 @@ class RegionNetworkEndpointGroupsRestTransport(RegionNetworkEndpointGroupsTransp
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.post(url, json=body,)
+        response = self._session.post(url, data=body,)
+
+        # Raise requests.exceptions.HTTPError if the status code is >= 400
+        response.raise_for_status()
 
         # Return the response
         return compute.Operation.from_json(response.content)
@@ -345,11 +358,11 @@ class RegionNetworkEndpointGroupsRestTransport(RegionNetworkEndpointGroupsTransp
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
         query_params = {
-            "pageToken": request.page_token,
             "filter": request.filter,
-            "orderBy": request.order_by,
-            "returnPartialSuccess": request.return_partial_success,
             "maxResults": request.max_results,
+            "orderBy": request.order_by,
+            "pageToken": request.page_token,
+            "returnPartialSuccess": request.return_partial_success,
         }
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
@@ -362,6 +375,9 @@ class RegionNetworkEndpointGroupsRestTransport(RegionNetworkEndpointGroupsTransp
         # Send the request
         response = self._session.get(url)
 
+        # Raise requests.exceptions.HTTPError if the status code is >= 400
+        response.raise_for_status()
+
         # Return the response
         return compute.NetworkEndpointGroupList.from_json(response.content)
 
