@@ -54,7 +54,7 @@ class SecurityPoliciesRestTransport(SecurityPoliciesTransport):
         credentials: credentials.Credentials = None,
         credentials_file: str = None,
         scopes: Sequence[str] = None,
-        ssl_channel_credentials: grpc.ChannelCredentials = None,
+        client_cert_source_for_mtls: Callable[[], Tuple[bytes, bytes]] = None,
         quota_project_id: Optional[str] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
@@ -73,8 +73,9 @@ class SecurityPoliciesRestTransport(SecurityPoliciesTransport):
                 This argument is ignored if ``channel`` is provided.
             scopes (Optional(Sequence[str])): A list of scopes. This argument is
                 ignored if ``channel`` is provided.
-            ssl_channel_credentials (grpc.ChannelCredentials): SSL credentials
-                for grpc channel. It is ignored if ``channel`` is provided.
+            client_cert_source_for_mtls (Callable[[], Tuple[bytes, bytes]]): Client
+                certificate to configure mutual TLS HTTP channel. It is ignored
+                if ``channel`` is provided.
             quota_project_id (Optional[str]): An optional project to use for billing
                 and quota.
             client_info (google.api_core.gapic_v1.client_info.ClientInfo):	
@@ -89,6 +90,8 @@ class SecurityPoliciesRestTransport(SecurityPoliciesTransport):
             host=host, credentials=credentials, client_info=client_info,
         )
         self._session = AuthorizedSession(self._credentials)
+        if client_cert_source_for_mtls:
+            self._session.configure_mtls_channel(client_cert_source_for_mtls)
 
     def add_rule(
         self,
@@ -143,7 +146,9 @@ class SecurityPoliciesRestTransport(SecurityPoliciesTransport):
 
         # Jsonify the request body
         body = compute.SecurityPolicyRule.to_json(
-            request.security_policy_rule_resource, including_default_value_fields=False
+            request.security_policy_rule_resource,
+            including_default_value_fields=False,
+            use_integers_for_enums=False,
         )
 
         # TODO(yon-mg): need to handle grpc transcoding and parse url correctly
@@ -166,7 +171,10 @@ class SecurityPoliciesRestTransport(SecurityPoliciesTransport):
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.post(url, json=body,)
+        response = self._session.post(url, data=body,)
+
+        # Raise requests.exceptions.HTTPError if the status code is >= 400
+        response.raise_for_status()
 
         # Return the response
         return compute.Operation.from_json(response.content)
@@ -246,6 +254,9 @@ class SecurityPoliciesRestTransport(SecurityPoliciesTransport):
         # Send the request
         response = self._session.delete(url)
 
+        # Raise requests.exceptions.HTTPError if the status code is >= 400
+        response.raise_for_status()
+
         # Return the response
         return compute.Operation.from_json(response.content)
 
@@ -301,6 +312,9 @@ class SecurityPoliciesRestTransport(SecurityPoliciesTransport):
         # Send the request
         response = self._session.get(url)
 
+        # Raise requests.exceptions.HTTPError if the status code is >= 400
+        response.raise_for_status()
+
         # Return the response
         return compute.SecurityPolicy.from_json(response.content)
 
@@ -355,6 +369,9 @@ class SecurityPoliciesRestTransport(SecurityPoliciesTransport):
         # Send the request
         response = self._session.get(url)
 
+        # Raise requests.exceptions.HTTPError if the status code is >= 400
+        response.raise_for_status()
+
         # Return the response
         return compute.SecurityPolicyRule.from_json(response.content)
 
@@ -411,7 +428,9 @@ class SecurityPoliciesRestTransport(SecurityPoliciesTransport):
 
         # Jsonify the request body
         body = compute.SecurityPolicy.to_json(
-            request.security_policy_resource, including_default_value_fields=False
+            request.security_policy_resource,
+            including_default_value_fields=False,
+            use_integers_for_enums=False,
         )
 
         # TODO(yon-mg): need to handle grpc transcoding and parse url correctly
@@ -434,7 +453,10 @@ class SecurityPoliciesRestTransport(SecurityPoliciesTransport):
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.post(url, json=body,)
+        response = self._session.post(url, data=body,)
+
+        # Raise requests.exceptions.HTTPError if the status code is >= 400
+        response.raise_for_status()
 
         # Return the response
         return compute.Operation.from_json(response.content)
@@ -471,11 +493,11 @@ class SecurityPoliciesRestTransport(SecurityPoliciesTransport):
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
         query_params = {
-            "pageToken": request.page_token,
             "filter": request.filter,
-            "orderBy": request.order_by,
-            "returnPartialSuccess": request.return_partial_success,
             "maxResults": request.max_results,
+            "orderBy": request.order_by,
+            "pageToken": request.page_token,
+            "returnPartialSuccess": request.return_partial_success,
         }
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
@@ -488,6 +510,9 @@ class SecurityPoliciesRestTransport(SecurityPoliciesTransport):
         # Send the request
         response = self._session.get(url)
 
+        # Raise requests.exceptions.HTTPError if the status code is >= 400
+        response.raise_for_status()
+
         # Return the response
         return compute.SecurityPolicyList.from_json(response.content)
 
@@ -524,11 +549,11 @@ class SecurityPoliciesRestTransport(SecurityPoliciesTransport):
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
         query_params = {
-            "pageToken": request.page_token,
             "filter": request.filter,
-            "orderBy": request.order_by,
-            "returnPartialSuccess": request.return_partial_success,
             "maxResults": request.max_results,
+            "orderBy": request.order_by,
+            "pageToken": request.page_token,
+            "returnPartialSuccess": request.return_partial_success,
         }
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
@@ -541,6 +566,9 @@ class SecurityPoliciesRestTransport(SecurityPoliciesTransport):
         # Send the request
         response = self._session.get(url)
 
+        # Raise requests.exceptions.HTTPError if the status code is >= 400
+        response.raise_for_status()
+
         # Return the response
         return compute.SecurityPoliciesListPreconfiguredExpressionSetsResponse.from_json(
             response.content
@@ -599,7 +627,9 @@ class SecurityPoliciesRestTransport(SecurityPoliciesTransport):
 
         # Jsonify the request body
         body = compute.SecurityPolicy.to_json(
-            request.security_policy_resource, including_default_value_fields=False
+            request.security_policy_resource,
+            including_default_value_fields=False,
+            use_integers_for_enums=False,
         )
 
         # TODO(yon-mg): need to handle grpc transcoding and parse url correctly
@@ -624,7 +654,10 @@ class SecurityPoliciesRestTransport(SecurityPoliciesTransport):
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.patch(url, json=body,)
+        response = self._session.patch(url, data=body,)
+
+        # Raise requests.exceptions.HTTPError if the status code is >= 400
+        response.raise_for_status()
 
         # Return the response
         return compute.Operation.from_json(response.content)
@@ -682,7 +715,9 @@ class SecurityPoliciesRestTransport(SecurityPoliciesTransport):
 
         # Jsonify the request body
         body = compute.SecurityPolicyRule.to_json(
-            request.security_policy_rule_resource, including_default_value_fields=False
+            request.security_policy_rule_resource,
+            including_default_value_fields=False,
+            use_integers_for_enums=False,
         )
 
         # TODO(yon-mg): need to handle grpc transcoding and parse url correctly
@@ -707,7 +742,10 @@ class SecurityPoliciesRestTransport(SecurityPoliciesTransport):
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.post(url, json=body,)
+        response = self._session.post(url, data=body,)
+
+        # Raise requests.exceptions.HTTPError if the status code is >= 400
+        response.raise_for_status()
 
         # Return the response
         return compute.Operation.from_json(response.content)
@@ -787,6 +825,9 @@ class SecurityPoliciesRestTransport(SecurityPoliciesTransport):
         # Send the request
         response = self._session.post(url)
 
+        # Raise requests.exceptions.HTTPError if the status code is >= 400
+        response.raise_for_status()
+
         # Return the response
         return compute.Operation.from_json(response.content)
 
