@@ -54,7 +54,7 @@ class TargetHttpProxiesRestTransport(TargetHttpProxiesTransport):
         credentials: credentials.Credentials = None,
         credentials_file: str = None,
         scopes: Sequence[str] = None,
-        ssl_channel_credentials: grpc.ChannelCredentials = None,
+        client_cert_source_for_mtls: Callable[[], Tuple[bytes, bytes]] = None,
         quota_project_id: Optional[str] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
@@ -73,8 +73,9 @@ class TargetHttpProxiesRestTransport(TargetHttpProxiesTransport):
                 This argument is ignored if ``channel`` is provided.
             scopes (Optional(Sequence[str])): A list of scopes. This argument is
                 ignored if ``channel`` is provided.
-            ssl_channel_credentials (grpc.ChannelCredentials): SSL credentials
-                for grpc channel. It is ignored if ``channel`` is provided.
+            client_cert_source_for_mtls (Callable[[], Tuple[bytes, bytes]]): Client
+                certificate to configure mutual TLS HTTP channel. It is ignored
+                if ``channel`` is provided.
             quota_project_id (Optional[str]): An optional project to use for billing
                 and quota.
             client_info (google.api_core.gapic_v1.client_info.ClientInfo):	
@@ -89,6 +90,8 @@ class TargetHttpProxiesRestTransport(TargetHttpProxiesTransport):
             host=host, credentials=credentials, client_info=client_info,
         )
         self._session = AuthorizedSession(self._credentials)
+        if client_cert_source_for_mtls:
+            self._session.configure_mtls_channel(client_cert_source_for_mtls)
 
     def aggregated_list(
         self,
@@ -122,12 +125,12 @@ class TargetHttpProxiesRestTransport(TargetHttpProxiesTransport):
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
         query_params = {
-            "pageToken": request.page_token,
             "filter": request.filter,
-            "orderBy": request.order_by,
             "includeAllScopes": request.include_all_scopes,
-            "returnPartialSuccess": request.return_partial_success,
             "maxResults": request.max_results,
+            "orderBy": request.order_by,
+            "pageToken": request.page_token,
+            "returnPartialSuccess": request.return_partial_success,
         }
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
@@ -140,6 +143,9 @@ class TargetHttpProxiesRestTransport(TargetHttpProxiesTransport):
         # Send the request
         response = self._session.get(url)
 
+        # Raise requests.exceptions.HTTPError if the status code is >= 400
+        response.raise_for_status()
+
         # Return the response
         return compute.TargetHttpProxyAggregatedList.from_json(response.content)
 
@@ -218,6 +224,9 @@ class TargetHttpProxiesRestTransport(TargetHttpProxiesTransport):
         # Send the request
         response = self._session.delete(url)
 
+        # Raise requests.exceptions.HTTPError if the status code is >= 400
+        response.raise_for_status()
+
         # Return the response
         return compute.Operation.from_json(response.content)
 
@@ -289,6 +298,9 @@ class TargetHttpProxiesRestTransport(TargetHttpProxiesTransport):
         # Send the request
         response = self._session.get(url)
 
+        # Raise requests.exceptions.HTTPError if the status code is >= 400
+        response.raise_for_status()
+
         # Return the response
         return compute.TargetHttpProxy.from_json(response.content)
 
@@ -345,7 +357,9 @@ class TargetHttpProxiesRestTransport(TargetHttpProxiesTransport):
 
         # Jsonify the request body
         body = compute.TargetHttpProxy.to_json(
-            request.target_http_proxy_resource, including_default_value_fields=False
+            request.target_http_proxy_resource,
+            including_default_value_fields=False,
+            use_integers_for_enums=False,
         )
 
         # TODO(yon-mg): need to handle grpc transcoding and parse url correctly
@@ -368,7 +382,10 @@ class TargetHttpProxiesRestTransport(TargetHttpProxiesTransport):
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.post(url, json=body,)
+        response = self._session.post(url, data=body,)
+
+        # Raise requests.exceptions.HTTPError if the status code is >= 400
+        response.raise_for_status()
 
         # Return the response
         return compute.Operation.from_json(response.content)
@@ -405,11 +422,11 @@ class TargetHttpProxiesRestTransport(TargetHttpProxiesTransport):
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
         query_params = {
-            "pageToken": request.page_token,
             "filter": request.filter,
-            "orderBy": request.order_by,
-            "returnPartialSuccess": request.return_partial_success,
             "maxResults": request.max_results,
+            "orderBy": request.order_by,
+            "pageToken": request.page_token,
+            "returnPartialSuccess": request.return_partial_success,
         }
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
@@ -422,6 +439,9 @@ class TargetHttpProxiesRestTransport(TargetHttpProxiesTransport):
         # Send the request
         response = self._session.get(url)
 
+        # Raise requests.exceptions.HTTPError if the status code is >= 400
+        response.raise_for_status()
+
         # Return the response
         return compute.TargetHttpProxyList.from_json(response.content)
 
@@ -478,7 +498,9 @@ class TargetHttpProxiesRestTransport(TargetHttpProxiesTransport):
 
         # Jsonify the request body
         body = compute.TargetHttpProxy.to_json(
-            request.target_http_proxy_resource, including_default_value_fields=False
+            request.target_http_proxy_resource,
+            including_default_value_fields=False,
+            use_integers_for_enums=False,
         )
 
         # TODO(yon-mg): need to handle grpc transcoding and parse url correctly
@@ -503,7 +525,10 @@ class TargetHttpProxiesRestTransport(TargetHttpProxiesTransport):
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.patch(url, json=body,)
+        response = self._session.patch(url, data=body,)
+
+        # Raise requests.exceptions.HTTPError if the status code is >= 400
+        response.raise_for_status()
 
         # Return the response
         return compute.Operation.from_json(response.content)
@@ -561,7 +586,9 @@ class TargetHttpProxiesRestTransport(TargetHttpProxiesTransport):
 
         # Jsonify the request body
         body = compute.UrlMapReference.to_json(
-            request.url_map_reference_resource, including_default_value_fields=False
+            request.url_map_reference_resource,
+            including_default_value_fields=False,
+            use_integers_for_enums=False,
         )
 
         # TODO(yon-mg): need to handle grpc transcoding and parse url correctly
@@ -586,7 +613,10 @@ class TargetHttpProxiesRestTransport(TargetHttpProxiesTransport):
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.post(url, json=body,)
+        response = self._session.post(url, data=body,)
+
+        # Raise requests.exceptions.HTTPError if the status code is >= 400
+        response.raise_for_status()
 
         # Return the response
         return compute.Operation.from_json(response.content)
