@@ -50,32 +50,32 @@ class computeCallTransformer(cst.CSTTransformer):
     'add_peering': ('network', 'networks_add_peering_request_resource', 'project', 'request_id', ),
     'add_resource_policies': ('disk', 'disks_add_resource_policies_request_resource', 'project', 'zone', 'request_id', ),
     'add_rule': ('project', 'security_policy', 'security_policy_rule_resource', ),
-    'add_signed_url_key': ('backend_bucket', 'project', 'signed_url_key_resource', 'request_id', ),
+    'add_signed_url_key': ('backend_service', 'project', 'signed_url_key_resource', 'request_id', ),
     'aggregated_list': ('project', 'filter', 'include_all_scopes', 'max_results', 'order_by', 'page_token', 'return_partial_success', ),
     'apply_updates_to_instances': ('instance_group_manager', 'instance_group_managers_apply_updates_request_resource', 'project', 'zone', ),
     'attach_disk': ('attached_disk_resource', 'instance', 'project', 'zone', 'force_attach', 'request_id', ),
-    'attach_network_endpoints': ('global_network_endpoint_groups_attach_endpoints_request_resource', 'network_endpoint_group', 'project', 'request_id', ),
+    'attach_network_endpoints': ('network_endpoint_group', 'network_endpoint_groups_attach_endpoints_request_resource', 'project', 'zone', 'request_id', ),
     'create_instances': ('instance_group_manager', 'instance_group_managers_create_instances_request_resource', 'project', 'zone', 'request_id', ),
     'create_snapshot': ('disk', 'project', 'snapshot_resource', 'zone', 'guest_flush', 'request_id', ),
-    'delete': ('address', 'project', 'region', 'request_id', ),
+    'delete': ('disk', 'project', 'zone', 'request_id', ),
     'delete_access_config': ('access_config', 'instance', 'network_interface', 'project', 'zone', 'request_id', ),
     'delete_instances': ('instance_group_manager', 'instance_group_managers_delete_instances_request_resource', 'project', 'zone', 'request_id', ),
     'delete_nodes': ('node_group', 'node_groups_delete_nodes_request_resource', 'project', 'zone', 'request_id', ),
     'delete_per_instance_configs': ('instance_group_manager', 'instance_group_managers_delete_per_instance_configs_req_resource', 'project', 'zone', ),
-    'delete_signed_url_key': ('backend_bucket', 'key_name', 'project', 'request_id', ),
+    'delete_signed_url_key': ('backend_service', 'key_name', 'project', 'request_id', ),
     'deprecate': ('deprecation_status_resource', 'image', 'project', 'request_id', ),
     'detach_disk': ('device_name', 'instance', 'project', 'zone', 'request_id', ),
-    'detach_network_endpoints': ('global_network_endpoint_groups_detach_endpoints_request_resource', 'network_endpoint_group', 'project', 'request_id', ),
+    'detach_network_endpoints': ('network_endpoint_group', 'network_endpoint_groups_detach_endpoints_request_resource', 'project', 'zone', 'request_id', ),
     'disable_xpn_host': ('project', 'request_id', ),
     'disable_xpn_resource': ('project', 'projects_disable_xpn_resource_request_resource', 'request_id', ),
     'enable_xpn_host': ('project', 'request_id', ),
     'enable_xpn_resource': ('project', 'projects_enable_xpn_resource_request_resource', 'request_id', ),
     'expand_ip_cidr_range': ('project', 'region', 'subnetwork', 'subnetworks_expand_ip_cidr_range_request_resource', 'request_id', ),
-    'get': ('accelerator_type', 'project', 'zone', ),
+    'get': ('disk', 'project', 'zone', ),
     'get_diagnostics': ('interconnect', 'project', ),
     'get_from_family': ('family', 'project', ),
     'get_guest_attributes': ('instance', 'project', 'zone', 'query_path', 'variable_key', ),
-    'get_health': ('backend_service', 'project', 'resource_group_reference_resource', ),
+    'get_health': ('backend_service', 'project', 'region', 'resource_group_reference_resource', ),
     'get_iam_policy': ('project', 'resource', 'zone', 'options_requested_policy_version', ),
     'get_nat_mapping_info': ('project', 'region', 'router', 'filter', 'max_results', 'order_by', 'page_token', 'return_partial_success', ),
     'get_router_status': ('project', 'region', 'router', ),
@@ -86,14 +86,14 @@ class computeCallTransformer(cst.CSTTransformer):
     'get_status': ('project', 'region', 'vpn_gateway', ),
     'get_xpn_host': ('project', ),
     'get_xpn_resources': ('project', 'filter', 'max_results', 'order_by', 'page_token', 'return_partial_success', ),
-    'insert': ('address_resource', 'project', 'region', 'request_id', ),
+    'insert': ('disk_resource', 'project', 'zone', 'request_id', 'source_image', ),
     'invalidate_cache': ('cache_invalidation_rule_resource', 'project', 'url_map', 'request_id', ),
     'list': ('project', 'zone', 'filter', 'max_results', 'order_by', 'page_token', 'return_partial_success', ),
     'list_available_features': ('project', 'filter', 'max_results', 'order_by', 'page_token', 'return_partial_success', ),
     'list_errors': ('instance_group_manager', 'project', 'zone', 'filter', 'max_results', 'order_by', 'page_token', 'return_partial_success', ),
     'list_instances': ('instance_group', 'instance_groups_list_instances_request_resource', 'project', 'zone', 'filter', 'max_results', 'order_by', 'page_token', 'return_partial_success', ),
     'list_managed_instances': ('instance_group_manager', 'project', 'zone', 'filter', 'max_results', 'order_by', 'page_token', 'return_partial_success', ),
-    'list_network_endpoints': ('network_endpoint_group', 'project', 'filter', 'max_results', 'order_by', 'page_token', 'return_partial_success', ),
+    'list_network_endpoints': ('network_endpoint_group', 'network_endpoint_groups_list_endpoints_request_resource', 'project', 'zone', 'filter', 'max_results', 'order_by', 'page_token', 'return_partial_success', ),
     'list_nodes': ('node_group', 'project', 'zone', 'filter', 'max_results', 'order_by', 'page_token', 'return_partial_success', ),
     'list_peering_routes': ('network', 'project', 'direction', 'filter', 'max_results', 'order_by', 'page_token', 'peering_name', 'region', 'return_partial_success', ),
     'list_per_instance_configs': ('instance_group_manager', 'project', 'zone', 'filter', 'max_results', 'order_by', 'page_token', 'return_partial_success', ),
@@ -138,12 +138,12 @@ class computeCallTransformer(cst.CSTTransformer):
     'set_security_policy': ('backend_service', 'project', 'security_policy_reference_resource', 'request_id', ),
     'set_service_account': ('instance', 'instances_set_service_account_request_resource', 'project', 'zone', 'request_id', ),
     'set_shielded_instance_integrity_policy': ('instance', 'project', 'shielded_instance_integrity_policy_resource', 'zone', 'request_id', ),
-    'set_ssl_certificates': ('project', 'region', 'region_target_https_proxies_set_ssl_certificates_request_resource', 'target_https_proxy', 'request_id', ),
+    'set_ssl_certificates': ('project', 'target_https_proxies_set_ssl_certificates_request_resource', 'target_https_proxy', 'request_id', ),
     'set_ssl_policy': ('project', 'ssl_policy_reference_resource', 'target_https_proxy', 'request_id', ),
     'set_tags': ('instance', 'project', 'tags_resource', 'zone', 'request_id', ),
-    'set_target': ('forwarding_rule', 'project', 'region', 'target_reference_resource', 'request_id', ),
+    'set_target': ('forwarding_rule', 'project', 'target_reference_resource', 'request_id', ),
     'set_target_pools': ('instance_group_manager', 'instance_group_managers_set_target_pools_request_resource', 'project', 'zone', 'request_id', ),
-    'set_url_map': ('project', 'region', 'target_http_proxy', 'url_map_reference_resource', 'request_id', ),
+    'set_url_map': ('project', 'target_https_proxy', 'url_map_reference_resource', 'request_id', ),
     'set_usage_export_bucket': ('project', 'usage_export_location_resource', 'request_id', ),
     'simulate_maintenance_event': ('instance', 'project', 'zone', ),
     'start': ('instance', 'project', 'zone', 'request_id', ),
@@ -158,8 +158,8 @@ class computeCallTransformer(cst.CSTTransformer):
     'update_peering': ('network', 'networks_update_peering_request_resource', 'project', 'request_id', ),
     'update_per_instance_configs': ('instance_group_manager', 'instance_group_managers_update_per_instance_configs_req_resource', 'project', 'zone', 'request_id', ),
     'update_shielded_instance_config': ('instance', 'project', 'shielded_instance_config_resource', 'zone', 'request_id', ),
-    'validate': ('project', 'region', 'region_url_maps_validate_request_resource', 'url_map', ),
-    'wait': ('operation', 'project', ),
+    'validate': ('project', 'url_map', 'url_maps_validate_request_resource', ),
+    'wait': ('operation', 'project', 'region', ),
 
     }
 
